==> dynamic_links-1.0.0.tar.gz: dynamic_links/src/Routing/DynamicLinksRoutes.php <==
<?php

namespace Drupal\dynamic_links\Routing;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\dynamic_links\Controller\DynamicLinksController;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Routing\Route;

/**
 * Provides routes for dynamic links.
 */
class DynamicLinksRoutes implements ContainerInjectionInterface {

  /**
   * Constructs the object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(
    protected EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Returns an array of route objects for dynamic links.
   *
   * @return \Symfony\Component\Routing\Route[]
   *   An array of route objects.
   */
  public function routes(): array {
    /** @var \Drupal\dynamic_links\DynamicLinkInterface[] $links */
    $links = $this->entityTypeManager->getStorage('dynamic_link')->loadMultiple();
    $routes = [];
    $route_template = new Route(
      '',
      [
        '_controller' => DynamicLinksController::class . '::redirect',
        'dynamic_link' => '',
      ],
      [
        '_custom_access' => DynamicLinksController::class . '::access',
      ],
      [
        'parameters' => [
          'dynamic_link' => [
            'type' => 'entity:dynamic_link',
          ],
        ],
      ]
    );
    foreach ($links as $link_id => $link) {
      if ($link->status()) {
        $routes["dynamic_link.$link_id"] = (clone $route_template)
          ->setPath($link->getUrl())
          ->setDefault('dynamic_link', $link_id);
      }
    }
    return $routes;
  }

}

==> dynamic_links-1.0.8.tar.gz: dynamic_links/src/Routing/DynamicLinksRoutes.php <==
<?php

namespace Drupal\dynamic_links\Routing;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\dynamic_links\Controller\DynamicLinksController;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Routing\Route;

/**
 * Provides routes for dynamic links.
 */
class DynamicLinksRoutes implements ContainerInjectionInterface {

  const ROUTE_PREFIX = 'dynamic_link.';

  /**
   * Constructs the object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(
    protected EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Returns an array of route objects for dynamic links.
   *
   * @return \Symfony\Component\Routing\Route[]
   *   An array of route objects.
   */
  public function routes(): array {
    /** @var \Drupal\dynamic_links\DynamicLinkInterface[] $links */
    $links = $this->entityTypeManager->getStorage('dynamic_link')->loadMultiple();
    $routes = [];
    $route_template = new Route(
      '',
      [
        '_controller' => DynamicLinksController::class . '::redirect',
        'dynamic_link' => '',
      ],
      [
        '_custom_access' => DynamicLinksController::class . '::access',
      ],
      [
        'parameters' => [
          'dynamic_link' => [
            'type' => 'entity:dynamic_link',
          ],
        ],
      ]
    );
    foreach ($links as $link_id => $link) {
      if ($link->status()) {
        $routes[static::ROUTE_PREFIX . $link_id] = (clone $route_template)
          ->setPath($link->getPath())
          ->setDefault('dynamic_link', $link_id);
      }
    }
    return $routes;
  }

}
